@@ -783,6 +783,13 @@ typedef struct cuStreamWaitValue32_ptsz_params_st {
     unsigned int flags;
 } cuStreamWaitValue32_ptsz_params;
 
+typedef struct cuStreamWaitValue64_ptsz_params_st {
+    CUstream stream;
+    CUdeviceptr addr;
+    cuuint64_t value;
+    unsigned int flags;
+} cuStreamWaitValue64_ptsz_params;
+
 typedef struct cuStreamWriteValue32_ptsz_params_st {
     CUstream stream;
     CUdeviceptr addr;
@@ -790,6 +797,13 @@ typedef struct cuStreamWriteValue32_ptsz_params_st {
     unsigned int flags;
 } cuStreamWriteValue32_ptsz_params;
 
+typedef struct cuStreamWriteValue64_ptsz_params_st {
+    CUstream stream;
+    CUdeviceptr addr;
+    cuuint64_t value;
+    unsigned int flags;
+} cuStreamWriteValue64_ptsz_params;
+
 typedef struct cuStreamBatchMemOp_ptsz_params_st {
     CUstream stream;
     unsigned int count;
@@ -803,6 +817,12 @@ typedef struct cuFuncGetAttribute_params_st {
     CUfunction hfunc;
 } cuFuncGetAttribute_params;
 
+typedef struct cuFuncSetAttribute_params_st {
+    CUfunction hfunc;
+    CUfunction_attribute attrib;
+    int value;
+} cuFuncSetAttribute_params;
+
 typedef struct cuFuncSetCacheConfig_params_st {
     CUfunction hfunc;
     CUfunc_cache config;
@@ -827,6 +847,25 @@ typedef struct cuLaunchKernel_ptsz_params_st {
     void **extra;
 } cuLaunchKernel_ptsz_params;
 
+typedef struct cuLaunchCooperativeKernel_ptsz_params_st {
+    CUfunction f;
+    unsigned int gridDimX;
+    unsigned int gridDimY;
+    unsigned int gridDimZ;
+    unsigned int blockDimX;
+    unsigned int blockDimY;
+    unsigned int blockDimZ;
+    unsigned int sharedMemBytes;
+    CUstream hStream;
+    void **kernelParams;
+} cuLaunchCooperativeKernel_ptsz_params;
+
+typedef struct cuLaunchCooperativeKernelMultiDevice_params_st {
+    CUDA_LAUNCH_PARAMS *launchParamsList;
+    unsigned int numDevices;
+    unsigned int flags;
+} cuLaunchCooperativeKernelMultiDevice_params;
+
 typedef struct cuFuncSetBlockShape_params_st {
     CUfunction hfunc;
     int x;
@@ -1122,13 +1161,6 @@ typedef struct cuDeviceCanAccessPeer_params_st {
     CUdevice peerDev;
 } cuDeviceCanAccessPeer_params;
 
-typedef struct cuDeviceGetP2PAttribute_params_st {
-    int *value;
-    CUdevice_P2PAttribute attrib;
-    CUdevice srcDevice;
-    CUdevice dstDevice;
-} cuDeviceGetP2PAttribute_params;
-
 typedef struct cuCtxEnablePeerAccess_params_st {
     CUcontext peerContext;
     unsigned int Flags;
@@ -1138,6 +1170,13 @@ typedef struct cuCtxDisablePeerAccess_params_st {
     CUcontext peerContext;
 } cuCtxDisablePeerAccess_params;
 
+typedef struct cuDeviceGetP2PAttribute_params_st {
+    int *value;
+    CUdevice_P2PAttribute attrib;
+    CUdevice srcDevice;
+    CUdevice dstDevice;
+} cuDeviceGetP2PAttribute_params;
+
 typedef struct cuGraphicsUnregisterResource_params_st {
     CUgraphicsResource resource;
 } cuGraphicsUnregisterResource_params;
@@ -1815,13 +1854,6 @@ typedef struct cuGraphicsUnmapResources_params_st {
     CUstream hStream;
 } cuGraphicsUnmapResources_params;
 
-typedef struct cuMemPrefetchAsync_params_st {
-    CUdeviceptr devPtr;
-    size_t count;
-    CUdevice dstDevice;
-    CUstream hStream;
-} cuMemPrefetchAsync_params;
-
 typedef struct cuStreamWriteValue32_params_st {
     CUstream stream;
     CUdeviceptr addr;
@@ -1836,9 +1868,43 @@ typedef struct cuStreamWaitValue32_params_st {
     unsigned int flags;
 } cuStreamWaitValue32_params;
 
+typedef struct cuStreamWriteValue64_params_st {
+    CUstream stream;
+    CUdeviceptr addr;
+    cuuint64_t value;
+    unsigned int flags;
+} cuStreamWriteValue64_params;
+
+typedef struct cuStreamWaitValue64_params_st {
+    CUstream stream;
+    CUdeviceptr addr;
+    cuuint64_t value;
+    unsigned int flags;
+} cuStreamWaitValue64_params;
+
 typedef struct cuStreamBatchMemOp_params_st {
     CUstream stream;
     unsigned int count;
     CUstreamBatchMemOpParams *paramArray;
     unsigned int flags;
 } cuStreamBatchMemOp_params;
+
+typedef struct cuMemPrefetchAsync_params_st {
+    CUdeviceptr devPtr;
+    size_t count;
+    CUdevice dstDevice;
+    CUstream hStream;
+} cuMemPrefetchAsync_params;
+
+typedef struct cuLaunchCooperativeKernel_params_st {
+    CUfunction f;
+    unsigned int gridDimX;
+    unsigned int gridDimY;
+    unsigned int gridDimZ;
+    unsigned int blockDimX;
+    unsigned int blockDimY;
+    unsigned int blockDimZ;
+    unsigned int sharedMemBytes;
+    CUstream hStream;
+    void **kernelParams;
+} cuLaunchCooperativeKernel_params;
