@@ -157,11 +157,11 @@ int enumEventDomains(CUdevice dev) {
                                                  (void*)&domainData.eventCollectionMethod);
         CHECK_CUPTI_ERROR(ptiStatus, "cuptiEventDomainGetAttribute");
 
-        printf ("Domain# %d\n", i+1);
+        printf ("Domain# %u\n", i+1);
         printf ("Id         = %d\n",   domainData.domainId);
         printf ("Name       = %s\n",   domainData.domainName);
-        printf ("Profiled instance count = %d\n", domainData.profiledInstanceCnt);
-        printf ("Total instance count = %d\n", domainData.totalInstanceCnt);
+        printf ("Profiled instance count = %u\n", domainData.profiledInstanceCnt);
+        printf ("Total instance count = %u\n", domainData.totalInstanceCnt);
 
         printf ("Event collection method = ");
         switch(domainData.eventCollectionMethod)
@@ -259,7 +259,7 @@ int enumEvents(CUpti_EventDomainID domainId) {
                                            (&eventData.category));
         CHECK_CUPTI_ERROR(ptiStatus, "cuptiEventGetAttribute");        
 
-        printf("Event# %d\n", i+1);
+        printf("Event# %u\n", i+1);
         printf("Id        = %d\n", eventData.Id.eventId);
         printf("Name      = %s\n", eventData.eventName);
         printf("Shortdesc = %s\n", eventData.shortDesc);
@@ -349,7 +349,7 @@ int enumMetrics(CUdevice dev) {
         CHECK_CUPTI_ERROR(ptiStatus, "cuptiEventGetAttribute");        
         checkNullTerminator(metricData.longDesc, size, DESC_LONG);
         
-        printf("Metric# %d\n", i+1);
+        printf("Metric# %u\n", i+1);
         printf("Id        = %d\n", metricData.Id.metricId);
         printf("Name      = %s\n", metricData.eventName);
         printf("Shortdesc = %s\n", metricData.shortDesc);
@@ -459,10 +459,11 @@ int main(int argc, char *argv[])
     printf("CUDA Device Id  : %d\n", deviceId);
     printf("CUDA Device Name: %s\n\n", deviceName);
 
-    err = cuDeviceComputeCapability( &computeCapabilityMajor, 
-                                     &computeCapabilityMinor, 
-                                     dev);
-    CHECK_CU_ERROR(err, "cuDeviceComputeCapability");
+    err = cuDeviceGetAttribute(&computeCapabilityMajor, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MAJOR, dev);
+    CHECK_CU_ERROR(err, "cuDeviceGetAttribute");
+
+    err = cuDeviceGetAttribute(&computeCapabilityMinor, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MINOR, dev);
+    CHECK_CU_ERROR(err, "cuDeviceGetAttribute");
 
     if (isOptionsFlagSet(FLAG_GET_DOMAINS)) {
         if (enumEventDomains(dev)) {
