@@ -99,7 +99,6 @@ typedef unsigned size_t;
 
 #if defined(__CUDACC_RTC__)
 #include "nvrtc_device_runtime.h"
-#include "ci_include.h"
 #include "device_functions.h"
 
 extern __host__ __device__  unsigned cudaConfigureCall(dim3 gridDim, 
@@ -173,7 +172,10 @@ struct  __device_builtin__ __nv_lambda_preheader_injection { };
  * ::cudaErrorLaunchFailure,
  * ::cudaErrorLaunchTimeout,
  * ::cudaErrorLaunchOutOfResources,
- * ::cudaErrorSharedObjectInitFailed
+ * ::cudaErrorSharedObjectInitFailed,
+ * ::cudaErrorInvalidPtx,
+ * ::cudaErrorNoKernelImageForDevice,
+ * ::cudaErrorJitCompilerNotFound
  * \notefnerr
  * \note_async
  * \note_null_stream
@@ -193,6 +195,66 @@ static __inline__ __host__ cudaError_t cudaLaunchKernel(
     return ::cudaLaunchKernel((const void *)func, gridDim, blockDim, args, sharedMem, stream);
 }
 
+/**
+ *\brief Launches a device function
+ *
+ * The function invokes kernel \p func on \p gridDim (\p gridDim.x × \p gridDim.y
+ * × \p gridDim.z) grid of blocks. Each block contains \p blockDim (\p blockDim.x ×
+ * \p blockDim.y × \p blockDim.z) threads.
+ *
+ * The device on which this kernel is invoked must have a non-zero value for
+ * the device attribute ::cudaDevAttrCooperativeLaunch.
+ *
+ * The total number of blocks launched cannot exceed the maximum number of blocks per
+ * multiprocessor as returned by ::cudaOccupancyMaxActiveBlocksPerMultiprocessor (or
+ * ::cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags) times the number of multiprocessors
+ * as specified by the device attribute ::cudaDevAttrMultiProcessorCount.
+ *
+ * The kernel cannot make use of CUDA dynamic parallelism.
+ *
+ * If the kernel has N parameters the \p args should point to array of N pointers.
+ * Each pointer, from <tt>args[0]</tt> to <tt>args[N - 1]</tt>, point to the region
+ * of memory from which the actual parameter will be copied.
+ *
+ * \p sharedMem sets the amount of dynamic shared memory that will be available to
+ * each thread block.
+ *
+ * \p stream specifies a stream the invocation is associated to.
+ *
+ * \param func        - Device function symbol
+ * \param gridDim     - Grid dimentions
+ * \param blockDim    - Block dimentions
+ * \param args        - Arguments
+ * \param sharedMem   - Shared memory (defaults to 0)
+ * \param stream      - Stream identifier (defaults to NULL)
+ *
+ * \return
+ * ::cudaSuccess,
+ * ::cudaErrorInvalidDeviceFunction,
+ * ::cudaErrorInvalidConfiguration,
+ * ::cudaErrorLaunchFailure,
+ * ::cudaErrorLaunchTimeout,
+ * ::cudaErrorLaunchOutOfResources,
+ * ::cudaErrorSharedObjectInitFailed
+ * \notefnerr
+ * \note_async
+ * \note_null_stream
+ *
+ * \ref ::cudaLaunchCooperativeKernel(const void *func, dim3 gridDim, dim3 blockDim, void **args, size_t sharedMem, cudaStream_t stream) "cudaLaunchCooperativeKernel (C API)"
+ */
+template<class T>
+static __inline__ __host__ cudaError_t cudaLaunchCooperativeKernel(
+  const T *func,
+  dim3 gridDim,
+  dim3 blockDim,
+  void **args,
+  size_t sharedMem = 0,
+  cudaStream_t stream = 0
+)
+{
+    return ::cudaLaunchCooperativeKernel((const void *)func, gridDim, blockDim, args, sharedMem, stream);
+}
+
 /**
  * \brief \hl Configure a device launch
  *
@@ -430,6 +492,7 @@ static __inline__ __host__ cudaError_t cudaHostGetDevicePointer(
  * that process, even if ::cudaDeviceReset has been called on those devices. These
  * environment variables are described in the CUDA programming guide under the
  * "CUDA environment variables" section.
+ * - On ARM, managed memory is not available on discrete gpu with Drive PX-2.
  *
  * \param devPtr - Pointer to allocated device memory
  * \param size   - Requested allocation size in bytes
@@ -437,8 +500,8 @@ static __inline__ __host__ cudaError_t cudaHostGetDevicePointer(
  *
  * \return
  * ::cudaSuccess,
- * ::cudaErrorMemoryAllocation
- * ::cudaErrorNotSupported
+ * ::cudaErrorMemoryAllocation,
+ * ::cudaErrorNotSupported,
  * ::cudaErrorInvalidValue
  *
  * \sa ::cudaMallocPitch, ::cudaFree, ::cudaMallocArray, ::cudaFreeArray,
@@ -519,7 +582,7 @@ static __inline__ __host__ cudaError_t cudaMallocManaged(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorNotReady,
- * ::cudaErrorInvalidValue
+ * ::cudaErrorInvalidValue,
  * ::cudaErrorInvalidResourceHandle
  * \notefnerr
  *
@@ -587,8 +650,8 @@ static __inline__ __host__ cudaError_t cudaMallocPitch(
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
  * ::cudaErrorInvalidSymbol,
- * ::cudaErrorInvalidDevicePointer,
- * ::cudaErrorInvalidMemcpyDirection
+ * ::cudaErrorInvalidMemcpyDirection,
+ * ::cudaErrorNoKernelImageForDevice
  * \notefnerr
  * \note_sync
  * \note_string_api_deprecation
@@ -639,8 +702,8 @@ static __inline__ __host__ cudaError_t cudaMemcpyToSymbol(
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
  * ::cudaErrorInvalidSymbol,
- * ::cudaErrorInvalidDevicePointer,
- * ::cudaErrorInvalidMemcpyDirection
+ * ::cudaErrorInvalidMemcpyDirection,
+ * ::cudaErrorNoKernelImageForDevice
  * \notefnerr
  * \note_async
  * \note_string_api_deprecation
@@ -685,8 +748,8 @@ static __inline__ __host__ cudaError_t cudaMemcpyToSymbolAsync(
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
  * ::cudaErrorInvalidSymbol,
- * ::cudaErrorInvalidDevicePointer,
- * ::cudaErrorInvalidMemcpyDirection
+ * ::cudaErrorInvalidMemcpyDirection,
+ * ::cudaErrorNoKernelImageForDevice
  * \notefnerr
  * \note_sync
  * \note_string_api_deprecation
@@ -737,8 +800,8 @@ static __inline__ __host__ cudaError_t cudaMemcpyFromSymbol(
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
  * ::cudaErrorInvalidSymbol,
- * ::cudaErrorInvalidDevicePointer,
- * ::cudaErrorInvalidMemcpyDirection
+ * ::cudaErrorInvalidMemcpyDirection,
+ * ::cudaErrorNoKernelImageForDevice
  * \notefnerr
  * \note_async
  * \note_string_api_deprecation
@@ -778,7 +841,8 @@ static __inline__ __host__ cudaError_t cudaMemcpyFromSymbolAsync(
  *
  * \return
  * ::cudaSuccess,
- * ::cudaErrorInvalidSymbol
+ * ::cudaErrorInvalidSymbol,
+ * ::cudaErrorNoKernelImageForDevice
  * \notefnerr
  *
  * \sa \ref ::cudaGetSymbolAddress(void**, const void*) "cudaGetSymbolAddress (C API)",
@@ -807,7 +871,8 @@ static __inline__ __host__ cudaError_t cudaGetSymbolAddress(
  *
  * \return
  * ::cudaSuccess,
- * ::cudaErrorInvalidSymbol
+ * ::cudaErrorInvalidSymbol,
+ * ::cudaErrorNoKernelImageForDevice
  * \notefnerr
  *
  * \sa \ref ::cudaGetSymbolAddress(void**, const T&) "cudaGetSymbolAddress (C++ API)",
@@ -841,7 +906,6 @@ static __inline__ __host__ cudaError_t cudaGetSymbolSize(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -886,7 +950,6 @@ static __inline__ __host__ cudaError_t cudaBindTexture(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -942,7 +1005,6 @@ static __inline__ __host__ cudaError_t cudaBindTexture(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -1000,7 +1062,6 @@ static __inline__ __host__ cudaError_t cudaBindTexture2D(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -1042,7 +1103,6 @@ static __inline__ __host__ cudaError_t cudaBindTexture2D(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -1080,7 +1140,6 @@ static __inline__ __host__ cudaError_t cudaBindTextureToArray(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -1121,7 +1180,6 @@ static __inline__ __host__ cudaError_t cudaBindTextureToArray(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -1159,7 +1217,6 @@ static __inline__ __host__ cudaError_t cudaBindTextureToMipmappedArray(
  * \return
  * ::cudaSuccess,
  * ::cudaErrorInvalidValue,
- * ::cudaErrorInvalidDevicePointer,
  * ::cudaErrorInvalidTexture
  * \notefnerr
  *
@@ -1798,7 +1855,10 @@ static __inline__ __host__ CUDART_DEVICE cudaError_t cudaOccupancyMaxPotentialBl
  * ::cudaErrorLaunchTimeout,
  * ::cudaErrorLaunchOutOfResources,
  * ::cudaErrorSharedObjectSymbolNotFound,
- * ::cudaErrorSharedObjectInitFailed
+ * ::cudaErrorSharedObjectInitFailed,
+ * ::cudaErrorInvalidPtx,
+ * ::cudaErrorNoKernelImageForDevice,
+ * ::cudaErrorJitCompilerNotFound
  * \notefnerr
  *
  * \ref ::cudaLaunchKernel(const T *func, dim3 gridDim, dim3 blockDim, void **args, size_t sharedMem, cudaStream_t stream) "cudaLaunchKernel (C++ API)",
@@ -1857,6 +1917,49 @@ static __inline__ __host__ cudaError_t cudaFuncGetAttributes(
   return ::cudaFuncGetAttributes(attr, (const void*)entry);
 }
 
+/**
+ * \brief \hl Set attributes for a given function
+ *
+ * This function sets the attributes of a function specified via \p entry.
+ * The parameter \p entry must be a pointer to a function that executes
+ * on the device. The parameter specified by \p entry must be declared as a \p __global__
+ * function. The enumeration defined by \p attr is set to the value defined by \p value
+ * If the specified function does not exist, then ::cudaErrorInvalidDeviceFunction is returned.
+ * If the specified attribute cannot be written, or if the value is incorrect, 
+ * then ::cudaErrorInvalidValue is returned.
+ *
+ * Valid values for \p attr are:
+ * ::cuFuncAttrMaxDynamicSharedMem - Maximum size of dynamic shared memory per block
+ * ::cuFuncAttrPreferredShmemCarveout - Preferred shared memory-L1 cache split ratio in percent of shared memory.
+ *
+ * \param entry - Function to get attributes of
+ * \param attr  - Attribute to set
+ * \param value - Value to set
+ *
+ * \return
+ * ::cudaSuccess,
+ * ::cudaErrorInitializationError,
+ * ::cudaErrorInvalidDeviceFunction,
+ * ::cudaErrorInvalidValue
+ * \notefnerr
+ *
+ * \ref ::cudaLaunchKernel(const T *func, dim3 gridDim, dim3 blockDim, void **args, size_t sharedMem, cudaStream_t stream) "cudaLaunchKernel (C++ API)",
+ * \ref ::cudaFuncSetCacheConfig(T*, enum cudaFuncCache) "cudaFuncSetCacheConfig (C++ API)",
+ * \ref ::cudaFuncGetAttributes(struct cudaFuncAttributes*, const void*) "cudaFuncGetAttributes (C API)",
+ * ::cudaSetDoubleForDevice,
+ * ::cudaSetDoubleForHost,
+ * \ref ::cudaSetupArgument(T, size_t) "cudaSetupArgument (C++ API)"
+ */
+template<class T>
+static __inline__ __host__ cudaError_t cudaFuncSetAttribute(
+  T                         *entry,
+  enum cudaFuncAttribute    attr,
+  int                       value
+)
+{
+  return ::cudaFuncSetAttribute((const void*)entry, attr, value);
+}
+
 /**
  * \brief \hl Binds an array to a surface
  *
