@@ -66,11 +66,19 @@ extern "C" {
 struct cusolverDnContext;
 typedef struct cusolverDnContext *cusolverDnHandle_t;
 
+struct syevjInfo;
+typedef struct syevjInfo *syevjInfo_t;
+
+struct gesvdjInfo;
+typedef struct gesvdjInfo *gesvdjInfo_t;
+
+
 cusolverStatus_t CUSOLVERAPI cusolverDnCreate(cusolverDnHandle_t *handle);
 cusolverStatus_t CUSOLVERAPI cusolverDnDestroy(cusolverDnHandle_t handle);
 cusolverStatus_t CUSOLVERAPI cusolverDnSetStream (cusolverDnHandle_t handle, cudaStream_t streamId);
 cusolverStatus_t CUSOLVERAPI cusolverDnGetStream(cusolverDnHandle_t handle, cudaStream_t *streamId);
 
+
 /* Cholesky factorization and its solver */
 cusolverStatus_t CUSOLVERAPI cusolverDnSpotrf_bufferSize( 
     cusolverDnHandle_t handle, 
@@ -124,6 +132,8 @@ cusolverStatus_t CUSOLVERAPI cusolverDnDpotrf(
     int Lwork, 
     int *devInfo );
 
+
+
 cusolverStatus_t CUSOLVERAPI cusolverDnCpotrf( 
     cusolverDnHandle_t handle, 
     cublasFillMode_t uplo, 
@@ -189,6 +199,91 @@ cusolverStatus_t CUSOLVERAPI cusolverDnZpotrs(
     int ldb,
     int *devInfo);
 
+/* batched Cholesky factorization and its solver */
+cusolverStatus_t CUSOLVERAPI cusolverDnSpotrfBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    float *Aarray[],
+    int lda,
+    int *infoArray,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDpotrfBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    double *Aarray[],
+    int lda,
+    int *infoArray,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCpotrfBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    cuComplex *Aarray[],
+    int lda,
+    int *infoArray,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZpotrfBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    cuDoubleComplex *Aarray[],
+    int lda,
+    int *infoArray,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSpotrsBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    int nrhs, /* only support rhs = 1*/
+    float *A[],
+    int lda,
+    float *B[],
+    int ldb,
+    int *d_info,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDpotrsBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    int nrhs, /* only support rhs = 1*/
+    double *A[],
+    int lda,
+    double *B[],
+    int ldb,
+    int *d_info,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCpotrsBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    int nrhs, /* only support rhs = 1*/
+    cuComplex *A[],
+    int lda,
+    cuComplex *B[],
+    int ldb,
+    int *d_info,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZpotrsBatched(
+    cusolverDnHandle_t handle,
+    cublasFillMode_t uplo,
+    int n,
+    int nrhs, /* only support rhs = 1*/
+    cuDoubleComplex *A[],
+    int lda,
+    cuDoubleComplex *B[],
+    int ldb,
+    int *d_info,
+    int batchSize);
+
 
 /* LU Factorization */
 cusolverStatus_t CUSOLVERAPI cusolverDnSgetrf_bufferSize(
@@ -1508,6 +1603,678 @@ cusolverStatus_t CUSOLVERAPI cusolverDnZhegvd(
     int *info);
 
 
+cusolverStatus_t CUSOLVERAPI cusolverDnCreateSyevjInfo(
+    syevjInfo_t *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDestroySyevjInfo(
+    syevjInfo_t info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXsyevjSetTolerance(
+    syevjInfo_t info,
+    double tolerance);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXsyevjSetMaxSweeps(
+    syevjInfo_t info,
+    int max_sweeps);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXsyevjSetSortEig(
+    syevjInfo_t info,
+    int sort_eig);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXsyevjGetResidual(
+    cusolverDnHandle_t handle,
+    syevjInfo_t info,
+    double *residual);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXsyevjGetSweeps(
+    cusolverDnHandle_t handle,
+    syevjInfo_t info,
+    int *executed_sweeps);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsyevjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo, 
+    int n,
+    const float *A,
+    int lda,
+    const float *W,
+    int *lwork,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsyevjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo, 
+    int n,
+    const double *A, 
+    int lda,
+    const double *W,
+    int *lwork,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCheevjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo, 
+    int n,
+    const cuComplex *A, 
+    int lda,
+    const float *W,
+    int *lwork,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZheevjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo, 
+    int n,
+    const cuDoubleComplex *A, 
+    int lda,
+    const double *W,
+    int *lwork,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsyevjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,   
+    float *A,
+    int lda,
+    float *W, 
+    float *work,
+    int lwork,
+    int *info, 
+    syevjInfo_t params,
+    int batchSize
+    );
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsyevjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo, 
+    int n,
+    double *A,
+    int lda,
+    double *W,
+    double *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCheevjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo, 
+    int n,
+    cuComplex *A,
+    int lda,
+    float *W,
+    cuComplex *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZheevjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo, 
+    int n,
+    cuDoubleComplex *A,
+    int lda,
+    double *W,
+    cuDoubleComplex *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params,
+    int batchSize
+    );
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsyevj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,
+    const float *A,
+    int lda,
+    const float *W,
+    int *lwork,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsyevj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,
+    const double *A,
+    int lda,
+    const double *W,
+    int *lwork,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCheevj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,
+    const cuComplex *A,
+    int lda,
+    const float *W,
+    int *lwork,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZheevj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo,
+    int n,
+    const cuDoubleComplex *A,
+    int lda,
+    const double *W,
+    int *lwork,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsyevj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo, 
+    int n,
+    float *A,
+    int lda,
+    float *W,
+    float *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsyevj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo,
+    int n,
+    double *A,
+    int lda,
+    double *W, 
+    double *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCheevj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo,
+    int n,
+    cuComplex *A,
+    int lda,
+    float *W, 
+    cuComplex *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZheevj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,
+    cuDoubleComplex *A,
+    int lda,
+    double *W, 
+    cuDoubleComplex *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsygvj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype, 
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo,
+    int n,
+    const float *A, 
+    int lda,
+    const float *B, 
+    int ldb,
+    const float *W,
+    int *lwork,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsygvj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype, 
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo,
+    int n,
+    const double *A, 
+    int lda,
+    const double *B,
+    int ldb,
+    const double *W,
+    int *lwork,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnChegvj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,
+    const cuComplex *A, 
+    int lda,
+    const cuComplex *B, 
+    int ldb,
+    const float *W,
+    int *lwork,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZhegvj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype,
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,
+    int n,
+    const cuDoubleComplex *A, 
+    int lda,
+    const cuDoubleComplex *B, 
+    int ldb,
+    const double *W,
+    int *lwork,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsygvj(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype, 
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo, 
+    int n,
+    float *A, 
+    int lda,
+    float *B, 
+    int ldb,
+    float *W,
+    float *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsygvj(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype, 
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo, 
+    int n,
+    double *A, 
+    int lda,
+    double *B,
+    int ldb,
+    double *W, 
+    double *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnChegvj(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype, 
+    cusolverEigMode_t jobz, 
+    cublasFillMode_t uplo,
+    int n,
+    cuComplex *A, 
+    int lda,
+    cuComplex *B, 
+    int ldb,
+    float *W,
+    cuComplex *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZhegvj(
+    cusolverDnHandle_t handle,
+    cusolverEigType_t itype, 
+    cusolverEigMode_t jobz,
+    cublasFillMode_t uplo,  
+    int n,
+    cuDoubleComplex *A, 
+    int lda,
+    cuDoubleComplex *B, 
+    int ldb,
+    double *W, 
+    cuDoubleComplex *work,
+    int lwork,
+    int *info,
+    syevjInfo_t params);
+
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCreateGesvdjInfo(
+    gesvdjInfo_t *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDestroyGesvdjInfo(
+    gesvdjInfo_t info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXgesvdjSetTolerance(
+    gesvdjInfo_t info,
+    double tolerance);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXgesvdjSetMaxSweeps(
+    gesvdjInfo_t info,
+    int max_sweeps);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXgesvdjSetSortEig(
+    gesvdjInfo_t info,
+    int sort_svd);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXgesvdjGetResidual(
+    cusolverDnHandle_t handle,
+    gesvdjInfo_t info,
+    double *residual);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnXgesvdjGetSweeps(
+    cusolverDnHandle_t handle,
+    gesvdjInfo_t info,
+    int *executed_sweeps);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSgesvdjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int m,                
+    int n,                
+    const float *A,    
+    int lda,           
+    const float *S, 
+    const float *U,   
+    int ldu, 
+    const float *V,
+    int ldv,  
+    int *lwork,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDgesvdjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int m,
+    int n,
+    const double *A, 
+    int lda,
+    const double *S,
+    const double *U,
+    int ldu,
+    const double *V,
+    int ldv,
+    int *lwork,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCgesvdjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int m,
+    int n,
+    const cuComplex *A,
+    int lda,
+    const float *S,
+    const cuComplex *U,
+    int ldu,
+    const cuComplex *V,
+    int ldv,
+    int *lwork,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZgesvdjBatched_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    int m, 
+    int n, 
+    const cuDoubleComplex *A,
+    int lda,
+    const double *S,
+    const cuDoubleComplex *U,
+    int ldu, 
+    const cuDoubleComplex *V,
+    int ldv,
+    int *lwork,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSgesvdjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    int m, 
+    int n, 
+    float *A, 
+    int lda, 
+    float *S, 
+    float *U,
+    int ldu,
+    float *V,
+    int ldv, 
+    float *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDgesvdjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int m,
+    int n,
+    double *A,
+    int lda,
+    double *S,
+    double *U,
+    int ldu,
+    double *V,
+    int ldv, 
+    double *work,
+    int lwork,
+    int *info, 
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCgesvdjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int m, 
+    int n,
+    cuComplex *A,
+    int lda,
+    float *S,
+    cuComplex *U,
+    int ldu,
+    cuComplex *V,
+    int ldv,
+    cuComplex *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZgesvdjBatched(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int m,
+    int n,
+    cuDoubleComplex *A,
+    int lda, 
+    double *S, 
+    cuDoubleComplex *U,
+    int ldu,
+    cuDoubleComplex *V,
+    int ldv,
+    cuDoubleComplex *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params,
+    int batchSize);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSgesvdj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    int econ,
+    int m,
+    int n, 
+    const float *A,
+    int lda,
+    const float *S,
+    const float *U,
+    int ldu, 
+    const float *V,
+    int ldv,
+    int *lwork,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDgesvdj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    int econ,
+    int m,
+    int n,
+    const double *A, 
+    int lda,
+    const double *S,
+    const double *U,
+    int ldu,
+    const double *V,
+    int ldv,
+    int *lwork,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCgesvdj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz, 
+    int econ,
+    int m,
+    int n,
+    const cuComplex *A,
+    int lda,
+    const float *S,
+    const cuComplex *U,
+    int ldu,
+    const cuComplex *V,
+    int ldv,
+    int *lwork,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZgesvdj_bufferSize(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int econ,
+    int m,
+    int n,
+    const cuDoubleComplex *A,
+    int lda,
+    const double *S,
+    const cuDoubleComplex *U,
+    int ldu,
+    const cuDoubleComplex *V,
+    int ldv, 
+    int *lwork,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSgesvdj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int econ,
+    int m,
+    int n,
+    float *A, 
+    int lda,
+    float *S,
+    float *U,
+    int ldu,
+    float *V,
+    int ldv,
+    float *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDgesvdj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int econ, 
+    int m, 
+    int n, 
+    double *A, 
+    int lda,
+    double *S,
+    double *U,
+    int ldu,
+    double *V,
+    int ldv,
+    double *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCgesvdj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int econ,
+    int m,
+    int n,
+    cuComplex *A,
+    int lda,
+    float *S,
+    cuComplex *U,
+    int ldu,
+    cuComplex *V,
+    int ldv,
+    cuComplex *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZgesvdj(
+    cusolverDnHandle_t handle,
+    cusolverEigMode_t jobz,
+    int econ,
+    int m,
+    int n,
+    cuDoubleComplex *A,
+    int lda,
+    double *S,
+    cuDoubleComplex *U, 
+    int ldu, 
+    cuDoubleComplex *V,
+    int ldv,
+    cuDoubleComplex *work,
+    int lwork,
+    int *info,
+    gesvdjInfo_t params);
+
+
+
+
+
 
 #if defined(__cplusplus)
 }
