@@ -51,6 +51,7 @@
 #define CUSOLVERSP_H_
 
 #include "cusparse.h"
+#include "cublas_v2.h"
 #include "cusolver_common.h"
 
 #if defined(__cplusplus)
@@ -78,7 +79,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpXcsrissymHost(
     const int *csrColIndA,
     int *issym);
 
-/* -------- GPU linear solver based on LU factorization
+/* -------- GPU linear solver by LU factorization
  *       solve A*x = b, A can be singular 
  * [ls] stands for linear solve
  * [v] stands for vector
@@ -141,7 +142,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsrlsvluHost(
     int *singularity);
 
 
-/* -------- GPU linear solver based on QR factorization
+/* -------- GPU linear solver by QR factorization
  *       solve A*x = b, A can be singular 
  * [ls] stands for linear solve
  * [v] stands for vector
@@ -205,7 +206,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsrlsvqr(
 
 
 
-/* -------- CPU linear solver based on QR factorization
+/* -------- CPU linear solver by QR factorization
  *       solve A*x = b, A can be singular 
  * [ls] stands for linear solve
  * [v] stands for vector
@@ -268,7 +269,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsrlsvqrHost(
     int *singularity);
 
 
-/* -------- CPU linear solver based on Cholesky factorization
+/* -------- CPU linear solver by Cholesky factorization
  *       solve A*x = b, A can be singular 
  * [ls] stands for linear solve
  * [v] stands for vector
@@ -333,7 +334,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsrlsvcholHost(
     cuDoubleComplex *x,
     int *singularity);
 
-/* -------- GPU linear solver based on Cholesky factorization
+/* -------- GPU linear solver by Cholesky factorization
  *       solve A*x = b, A can be singular 
  * [ls] stands for linear solve
  * [v] stands for vector
@@ -404,7 +405,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsrlsvchol(
 
 
 
-/* ----------- CPU least square solver based on QR factorization
+/* ----------- CPU least square solver by QR factorization
  *       solve min|b - A*x| 
  * [lsq] stands for least square
  * [v] stands for vector
@@ -474,7 +475,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsrlsqvqrHost(
     int *p,
     double *min_norm);
 
-/* --------- CPU eigenvalue solver based on shift inverse
+/* --------- CPU eigenvalue solver by shift inverse
  *      solve A*x = lambda * x 
  *   where lambda is the eigenvalue nearest mu0.
  * [eig] stands for eigenvalue solver
@@ -541,7 +542,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpZcsreigvsiHost(
     cuDoubleComplex *x);
 
 
-/* --------- GPU eigenvalue solver based on shift inverse
+/* --------- GPU eigenvalue solver by shift inverse
  *      solve A*x = lambda * x 
  *   where lambda is the eigenvalue nearest mu0.
  * [eig] stands for eigenvalue solver
@@ -674,7 +675,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpXcsrsymrcmHost(
     int *p);
 
 /* --------- CPU symmdq 
- *   Symmetric minimum degree algorithm based on quotient graph
+ *   Symmetric minimum degree algorithm by quotient graph
  *
  */
 cusolverStatus_t CUSOLVERAPI cusolverSpXcsrsymmdqHost(
@@ -687,7 +688,7 @@ cusolverStatus_t CUSOLVERAPI cusolverSpXcsrsymmdqHost(
     int *p);
 
 /* --------- CPU symmdq 
- *   Symmetric Approximate minimum degree algorithm based on quotient graph
+ *   Symmetric Approximate minimum degree algorithm by quotient graph
  *
  */
 cusolverStatus_t CUSOLVERAPI cusolverSpXcsrsymamdHost(
