@@ -51,6 +51,7 @@
 #define __DRIVER_TYPES_H__
 
 #include "host_defines.h"
+#include "vector_types.h"
 
 /**
  * \defgroup CUDART_TYPES Data types used by CUDA Runtime
@@ -142,6 +143,20 @@
 #define cudaCpuDeviceId                     ((int)-1) /**< Device id that represents the CPU */
 #define cudaInvalidDeviceId                 ((int)-2) /**< Device id that represents an invalid device */
 
+/**
+ * If set, each kernel launched as part of ::cudaLaunchCooperativeKernelMultiDevice only
+ * waits for prior work in the stream corresponding to that GPU to complete before the
+ * kernel begins execution.
+ */
+#define cudaCooperativeLaunchMultiDeviceNoPreSync  0x01
+
+/**
+ * If set, any subsequent work pushed in a stream that participated in a call to
+ * ::cudaLaunchCooperativeKernelMultiDevice will only wait for the kernel launched on
+ * the GPU corresponding to that stream to complete before it begins execution.
+ */
+#define cudaCooperativeLaunchMultiDeviceNoPostSync 0x02
+
 #endif /* !__CUDA_INTERNAL_COMPILATION__ */
 
 /*******************************************************************************
@@ -732,6 +747,22 @@ enum __device_builtin__ cudaError
      */
     cudaErrorNvlinkUncorrectable          =     80,
 
+    /**
+     * This indicates that the PTX JIT compiler library was not found. The JIT Compiler
+     * library is used for PTX compilation. The runtime may fall back to compiling PTX
+     * if an application does not contain a suitable binary for the current device.
+     */
+    cudaErrorJitCompilerNotFound          =     81,
+
+    /**
+     * This error indicates that the number of blocks launched per grid for a kernel that was
+     * launched via either ::cudaLaunchCooperativeKernel or ::cudaLaunchCooperativeKernelMultiDevice
+     * exceeds the maximum number of blocks as allowed by ::cudaOccupancyMaxActiveBlocksPerMultiprocessor
+     * or ::cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags times the number of multiprocessors
+     * as specified by the device attribute ::cudaDevAttrMultiProcessorCount.
+     */
+    cudaErrorCooperativeLaunchTooLarge    =     82,
+
     /**
      * This indicates an internal startup failure in the CUDA runtime.
      */
@@ -1116,6 +1147,30 @@ struct __device_builtin__ cudaFuncAttributes
     * user specified option "-Xptxas --dlcm=ca" set.
     */
    int cacheModeCA;
+
+   /**
+    * The maximum size in bytes of dynamic shared memory per block for 
+    * this function. Any launch must have a dynamic shared memory size
+    * smaller than this value.
+    */
+   int maxDynamicSharedSizeBytes;
+
+   /**
+    * On devices where the L1 cache and shared memory use the same hardware resources, 
+    * this sets the shared memory carveout preference, in percent of the total resources. 
+    * This is only a hint, and the driver can choose a different ratio if required to execute the function.
+    */
+   int preferredShmemCarveout;
+};
+
+/**
+ * CUDA function attributes that can be set using cudaFuncSetAttribute
+ */
+enum __device_builtin__ cudaFuncAttribute
+{
+    cudaFuncAttributeMaxDynamicSharedMemorySize = 8, /**< Maximum dynamic shared memory size */
+    cudaFuncAttributePreferredSharedMemoryCarveout = 9, /**< Preferred shared memory-L1 cache split ratio */
+    cudaFuncAttributeMax
 };
 
 /**
@@ -1140,6 +1195,15 @@ enum __device_builtin__ cudaSharedMemConfig
     cudaSharedMemBankSizeEightByte = 2
 };
 
+/** 
+ * Shared memory carveout configurations
+ */
+enum __device_builtin__ cudaSharedCarveout {
+    cudaSharedmemCarveoutDefault      = -1,  /* * < no preference for shared memory or L1 (default) */
+    cudaSharedmemCarveoutMaxShared    = 100, /* * < prefer maximum available shared memory, minimum L1 cache */
+    cudaSharedmemCarveoutMaxL1        = 0    /* * < prefer maximum available L1 cache, minimum shared memory */
+};
+
 /**
  * CUDA device compute modes
  */
@@ -1290,7 +1354,13 @@ enum __device_builtin__ cudaDeviceAttr
     cudaDevAttrPageableMemoryAccess           = 88, /**< Device supports coherently accessing pageable memory without calling cudaHostRegister on it */
     cudaDevAttrConcurrentManagedAccess        = 89, /**< Device can coherently access managed memory concurrently with the CPU */
     cudaDevAttrComputePreemptionSupported     = 90, /**< Device supports Compute Preemption */
-    cudaDevAttrCanUseHostPointerForRegisteredMem = 91 /**< Device can access host registered memory at the same virtual address as the CPU */
+    cudaDevAttrCanUseHostPointerForRegisteredMem = 91, /**< Device can access host registered memory at the same virtual address as the CPU */
+    cudaDevAttrReserved92                     = 92,
+    cudaDevAttrReserved93                     = 93,
+    cudaDevAttrReserved94                     = 94,
+    cudaDevAttrCooperativeLaunch              = 95, /**< Device supports launching cooperative kernels via ::cudaLaunchCooperativeKernel*/
+    cudaDevAttrCooperativeMultiDeviceLaunch   = 96, /**< Device can participate in cooperative kernels launched via ::cudaLaunchCooperativeKernelMultiDevice */
+    cudaDevAttrMaxSharedMemoryPerBlockOptin   = 97 /**< The maximum optin shared memory per block. This value may vary by chip. See ::cudaFuncSetAttribute */
 };
 
 /**
@@ -1373,6 +1443,11 @@ struct __device_builtin__ cudaDeviceProp
     int    singleToDoublePrecisionPerfRatio; /**< Ratio of single precision performance (in floating-point operations per second) to double precision performance */
     int    pageableMemoryAccess;       /**< Device supports coherently accessing pageable memory without calling cudaHostRegister on it */
     int    concurrentManagedAccess;    /**< Device can coherently access managed memory concurrently with the CPU */
+    int    computePreemptionSupported; /**< Device supports Compute Preemption */
+    int    canUseHostPointerForRegisteredMem; /**< Device can access host registered memory at the same virtual address as the CPU */
+    int    cooperativeLaunch;          /**< Device supports launching cooperative kernels via ::cudaLaunchCooperativeKernel */
+    int    cooperativeMultiDeviceLaunch; /**< Device can participate in cooperative kernels launched via ::cudaLaunchCooperativeKernelMultiDevice */
+    size_t sharedMemPerBlockOptin;     /**< Per device maximum shared memory per block usable by special opt in */
 };
 
 #define cudaDevicePropDontCare                             \
@@ -1443,6 +1518,11 @@ struct __device_builtin__ cudaDeviceProp
           0,         /* int    singleToDoublePrecisionPerfRatio */ \
           0,         /* int    pageableMemoryAccess     */ \
           0,         /* int    concurrentManagedAccess  */ \
+          0,         /* int    computePreemptionSupported */ \
+          0,         /* int    canUseHostPointerForRegisteredMem */ \
+          0,         /* int    cooperativeLaunch */ \
+          0,         /* int    cooperativeMultiDeviceLaunch */ \
+          0,         /* size_t sharedMemPerBlockOptin */ \
         } /**< Empty device properties */
 
 /**
@@ -1502,6 +1582,28 @@ typedef __device_builtin__ struct CUuuid_st cudaUUID_t;
  */
 typedef __device_builtin__ enum cudaOutputMode cudaOutputMode_t;
 
+/**
+ * CUDA cooperative group scope
+ */
+enum __device_builtin__ cudaCGScope {
+    cudaCGScopeInvalid   = 0, /**< Invalid cooperative group scope */
+    cudaCGScopeGrid      = 1, /**< Scope represented by a grid_group */
+    cudaCGScopeMultiGrid = 2  /**< Scope represented by a multi_grid_group */
+};
+
+/**
+ * CUDA launch parameters
+ */
+struct __device_builtin__ cudaLaunchParams
+{
+    void *func;          /**< Device function symbol */
+    dim3 gridDim;        /**< Grid dimentions */
+    dim3 blockDim;       /**< Block dimentions */
+    void **args;         /**< Arguments */
+    size_t sharedMem;    /**< Shared memory */
+    cudaStream_t stream; /**< Stream identifier */
+};
+
 /** @} */
 /** @} */ /* END CUDART_TYPES */
 
