@@ -1,4 +1,4 @@
- /* Copyright 2009-2015 NVIDIA Corporation.  All rights reserved. 
+ /* Copyright 2009-2016 NVIDIA Corporation.  All rights reserved. 
   * 
   * NOTICE TO LICENSEE: 
   * 
@@ -256,7 +256,8 @@ typedef enum
     NPP_CUDA_6_0             = 600, /**<  Indicates that CUDA 6.0 capable device is machine's default device */
     NPP_CUDA_6_1             = 610, /**<  Indicates that CUDA 6.1 capable device is machine's default device */
     NPP_CUDA_6_2             = 620, /**<  Indicates that CUDA 6.2 capable device is machine's default device */
-    NPP_CUDA_6_3             = 630  /**<  Indicates that CUDA 6.3 or better is machine's default device */
+    NPP_CUDA_6_3             = 630, /**<  Indicates that CUDA 6.3 capable device is machine's default device */
+    NPP_CUDA_7_0             = 700  /**<  Indicates that CUDA 7.0 or better is machine's default device */
 } NppGpuComputeCapability;
 
 typedef struct 
@@ -398,6 +399,14 @@ typedef struct
     int y;      /**<  y-coordinate. */
 } NppiPoint;
 
+/** 
+ * 2D Polar Point
+ */
+typedef struct {
+    Npp32f rho;
+    Npp32f theta;
+} NppPointPolar;
+
 /**
  * 2D Size
  * This struct typically represents the size of a a rectangular region in
@@ -515,7 +524,9 @@ typedef enum {
     NPP_ALG_HINT_ACCURATE
 } NppHintAlgorithm;
 
-/* Alpha composition controls */
+/* 
+ * Alpha composition controls. 
+ */
 
 typedef enum {
     NPPI_OP_ALPHA_OVER,
@@ -534,6 +545,24 @@ typedef enum {
 } NppiAlphaOp;
 
 
+/** 
+ * The NppiHOGConfig structure defines the configuration parameters for the HOG descriptor: 
+ */
+ 
+typedef struct 
+{
+    int      cellSize;             /**<  square cell size (pixels). */
+    int      histogramBlockSize;   /**<  square histogram block size (pixels). */
+    int      nHistogramBins;       /**<  required number of histogram bins. */
+    NppiSize detectionWindowSize;  /**<  detection window size (pixels). */
+} NppiHOGConfig;
+
+#define NPP_HOG_MAX_CELL_SIZE                          (16) /**< max horizontal/vertical pixel size of cell.   */
+#define NPP_HOG_MAX_BLOCK_SIZE                         (64) /**< max horizontal/vertical pixel size of block.  */
+#define NPP_HOG_MAX_BINS_PER_CELL                      (16) /**< max number of histogram bins. */
+#define NPP_HOG_MAX_CELLS_PER_DESCRIPTOR              (256) /**< max number of cells in a descriptor window.   */
+#define NPP_HOG_MAX_OVERLAPPING_BLOCKS_PER_DESCRIPTOR (256) /**< max number of overlapping blocks in a descriptor window.   */
+#define NPP_HOG_MAX_DESCRIPTOR_LOCATIONS_PER_CALL     (128) /**< max number of descriptor window locations per function call.   */
 
 typedef struct
 {
