@@ -1,4 +1,4 @@
- /* Copyright 2009-2014 NVIDIA Corporation.  All rights reserved. 
+ /* Copyright 2009-2016 NVIDIA Corporation.  All rights reserved. 
   * 
   * NOTICE TO LICENSEE: 
   * 
@@ -71,7 +71,7 @@ extern "C" {
  *
  * @{
  *
- * These functions can be found in either the nppi or nppicom libraries. Linking to only the sub-libraries that you use can significantly
+ * These functions can be found in the nppicom library. Linking to only the sub-libraries that you use can significantly
  * save link time, application load time, and CUDA runtime startup time when using dynamic libraries.
  *
  */
@@ -255,8 +255,6 @@ nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R_NEW(const Npp8u  * pSrc, int nSrcStep,
                                         const Npp8u * pQuantizationTable, NppiSize oSizeROI,
                                         NppiDCTState* pState);
 
-
-
 /**
  * Inverse DCT, de-quantization and level shift part of the JPEG decoding.
  * Input is expected in 64x1 macro blocks and output is expected to be in 8x8
@@ -284,7 +282,60 @@ nppiDCTQuantInv8x8LS_JPEG_16s8u_C1R_NEW(const Npp16s * pSrc, int nSrcStep,
                                         const Npp8u * pQuantizationTable, NppiSize oSizeROI,
                                         NppiDCTState* pState);
                                     
+/**
+ * Forward DCT, quantization and level shift part of the JPEG encoding, 16-bit short integer.
+ * Input is expected in 8x8 macro blocks and output is expected to be in 64x1
+ * macro blocks. The new version of the primitive takes the ROI in image pixel size and
+ * works with DCT coefficients that are in zig-zag order.
+ *
+ * \param pSrc \ref source_image_pointer.
+ * \param nSrcStep \ref source_image_line_step.
+ * \param pDst \ref destination_image_pointer.
+ * \param nDstStep Image width in pixels x 8 x sizeof(Npp16s).
+ * \param pQuantizationTable Quantization Table in zig-zag order.
+ * \param oSizeROI \ref roi_specification.
+ * \param pState Pointer to DCT state structure. This structure must be
+ *          initialized allocated and initialized using nppiDCTInitAlloc(). 
+ * \return Error codes:
+ *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
+ *           8 width/height.
+ *         - ::NPP_STEP_ERROR If input image width is not multiple of 8 or does not
+ *           match ROI.
+ *         - ::NPP_NULL_POINTER_ERROR If the destination pointer is 0.
+ */
+NppStatus
+nppiDCTQuant16Fwd8x8LS_JPEG_8u16s_C1R_NEW(const Npp8u  * pSrc, int nSrcStep,
+                                          Npp16s * pDst, int nDstStep,
+                                          const Npp16u * pQuantizationTable, NppiSize oSizeROI,
+                                          NppiDCTState* pState);
 
+/**
+ * Inverse DCT, de-quantization and level shift part of the JPEG decoding, 16-bit short integer.
+ * Input is expected in 64x1 macro blocks and output is expected to be in 8x8
+ * macro blocks. The new version of the primitive takes the ROI in image pixel size and
+ * works with DCT coefficients that are in zig-zag order.
+ *
+ * \param pSrc \ref source_image_pointer.
+ * \param nSrcStep Image width in pixels x 8 x sizeof(Npp16s).
+ * \param pDst \ref destination_image_pointer.
+ * \param nDstStep \ref destination_image_line_step.
+ * \param pQuantizationTable Quantization Table in zig-zag order.
+ * \param oSizeROI \ref roi_specification.
+ * \param pState Pointer to DCT state structure. This structure must be
+ *          initialized allocated and initialized using nppiDCTInitAlloc().  
+ * \return Error codes:
+ *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
+ *           8 width/height.
+ *         - ::NPP_STEP_ERROR If input image width is not multiple of 8 or does not
+ *           match ROI.
+ *         - ::NPP_NULL_POINTER_ERROR If the destination pointer is 0.
+ */
+NppStatus
+nppiDCTQuant16Inv8x8LS_JPEG_16s8u_C1R_NEW(const Npp16s * pSrc, int nSrcStep,
+                                          Npp8u  * pDst, int nDstStep,
+                                          const Npp16u * pQuantizationTable, NppiSize oSizeROI,
+                                          NppiDCTState* pState);
+                                          
 /** @} image_quantization */
 
 #if defined (__cplusplus)
@@ -395,8 +446,6 @@ nppiDecodeHuffmanScanHost_JPEG_8u16s_P1R(const Npp8u  * pSrc, Npp32s nLength,
                     NppiDecodeHuffmanSpec * apHuffmanACTable[3], 
                     NppiSize aSizeROI[3]);
 
-/** @} image_compression */
-
 #if defined (__cplusplus)
 struct NppiEncodeHuffmanSpec;
 #else
@@ -459,6 +508,7 @@ nppiEncodeHuffmanSpecFree_JPEG(NppiEncodeHuffmanSpec  *pHuffmanSpec);
  * \param pHuffmanTableDC DC Huffman table.
  * \param pHuffmanTableAC AC Huffman table.
  * \param oSizeROI \ref roi_specification.
+ * \param pTempStorage Temporary storage.
  * \return Error codes:
  *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
  *           8 width/height.
@@ -469,7 +519,7 @@ nppiEncodeHuffmanSpecFree_JPEG(NppiEncodeHuffmanSpec  *pHuffmanSpec);
  */
 NppStatus
 nppiEncodeHuffmanScan_JPEG_8u16s_P1R(const Npp16s * pSrc, Npp32s nSrcStep,
-                    Npp32s restartInterval, Npp32s Ss, Npp32s Se, Npp32s Ah, Npp32s Al,
+                    Npp32s nRestartInterval, Npp32s nSs, Npp32s nSe, Npp32s nAh, Npp32s nAl,
                     Npp8u  * pDst, Npp32s* nLength,
                     NppiEncodeHuffmanSpec  * pHuffmanTableDC, 
                     NppiEncodeHuffmanSpec  * pHuffmanTableAC, 
@@ -490,9 +540,10 @@ nppiEncodeHuffmanScan_JPEG_8u16s_P1R(const Npp16s * pSrc, Npp32s nSrcStep,
  * \param nAl Bit Approximation Low, see JPEG standard.
  * \param pDst Byte-stuffed huffman encoded JPEG scan.
  * \param nLength Byte length of the huffman encoded JPEG scan.
- * \param apHuffmanTableDC DC Huffman tables.
- * \param apHuffmanTableAC AC Huffman tables.
+ * \param apHuffmanDCTable DC Huffman tables.
+ * \param apHuffmanACTable AC Huffman tables.
  * \param aSizeROI \ref roi_specification.
+ * \param pTempStorage Temporary storage.
  * \return Error codes:
  *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
  *           8 width/height.
@@ -527,9 +578,10 @@ nppiEncodeHuffmanScan_JPEG_8u16s_P1R(const Npp16s * pSrc, Npp32s nSrcStep,
  * \param hpTableDC Host pointer to the table of the huffman tree for DC component.
  * \param hpCodesAC Host pointer to the code of the huffman tree for AC component.
  * \param hpTableAC Host pointer to the table of the huffman tree for AC component.
-* \param pHuffmanTableDC DC Huffman table.
- * \param pHuffmanTableAC AC Huffman table.
+ * \param pHuffmanDCTable DC Huffman table.
+ * \param pHuffmanACTable AC Huffman table.
  * \param oSizeROI \ref roi_specification.
+ * \param pTempStorage Temporary storage.
  * \return Error codes:
  *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
  *           8 width/height.
@@ -545,8 +597,8 @@ nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P1R(const Npp16s * pSrc, Npp32s nSrcSte
                                              Npp8u * pDst, Npp32s * pLength,
                                              Npp8u * hpCodesDC, Npp8u * hpTableDC,
                                              Npp8u * hpCodesAC, Npp8u * hpTableAC,
-                                             NppiEncodeHuffmanSpec * aHuffmanDCTable, 
-                                             NppiEncodeHuffmanSpec * aHuffmanACTable, 
+                                             NppiEncodeHuffmanSpec * pHuffmanDCTable, 
+                                             NppiEncodeHuffmanSpec * pHuffmanACTable, 
                                              NppiSize oSizeROI, Npp8u * pTempStorage);
 
 /**
@@ -566,9 +618,10 @@ nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P1R(const Npp16s * pSrc, Npp32s nSrcSte
  * \param hpTableDC Host pointer to the table of the huffman tree for DC component.
  * \param hpCodesAC Host pointer to the code of the huffman tree for AC component.
  * \param hpTableAC Host pointer to the table of the huffman tree for AC component.
- * \param apHuffmanTableDC DC Huffman tables.
- * \param apHuffmanTableAC AC Huffman tables.
- * \param aSizeROI \ref roi_specification.
+ * \param apHuffmanDCTable DC Huffman tables.
+ * \param apHuffmanACTable AC Huffman tables.
+ * \param oSizeROI \ref roi_specification.
+ * \param pTempStorage Temporary storage.
  * \return Error codes:
  *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
  *           8 width/height.
@@ -578,14 +631,14 @@ nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P1R(const Npp16s * pSrc, Npp32s nSrcSte
  *         - ::NPP_NOT_SUFFICIENT_COMPUTE_CAPABILITY If the device has compute capability < 2.0.
  */
 NppStatus
-nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P3R(Npp16s * pSrc[3], Npp32s aSrcStep[3],
+nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P3R(Npp16s * apSrc[3], Npp32s aSrcStep[3],
                                              Npp32s nRestartInterval, Npp32s nSs, 
                                              Npp32s nSe, Npp32s nAh, Npp32s nAl,
                                              Npp8u * pDst, Npp32s * pLength,
                                              Npp8u * hpCodesDC[3], Npp8u * hpTableDC[3],
                                              Npp8u * hpCodesAC[3], Npp8u * hpTableAC[3],
-                                             NppiEncodeHuffmanSpec * aHuffmanDCTable[3], 
-                                             NppiEncodeHuffmanSpec * aHuffmanACTable[3], 
+                                             NppiEncodeHuffmanSpec * apHuffmanDCTable[3], 
+                                             NppiEncodeHuffmanSpec * apHuffmanACTable[3], 
                                              NppiSize oSizeROI[3], Npp8u * pTempStorage);
 
 /**
@@ -594,6 +647,7 @@ nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P3R(Npp16s * pSrc[3], Npp32s aSrcStep[3
  * \see nppiEncodeHuffmanScan_JPEG_8u16s_P1R(), nppiEncodeHuffmanScan_JPEG_8u16s_P3R().
  * 
  * \param oSize Image Dimension.
+ * \param nChannels Number of channels in the image.
  * \param pBufSize Pointer to variable that returns the size of the
  *        temporary buffer. 
  *
@@ -604,12 +658,11 @@ nppiEncodeOptimizeHuffmanScan_JPEG_8u16s_P3R(Npp16s * pSrc[3], Npp32s aSrcStep[3
  * \return NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
  *         pointer is NULL
  */
-NppStatus nppiEncodeHuffmanGetSize(NppiSize oSize, int nChannels, int * pBufSize);
+NppStatus nppiEncodeHuffmanGetSize(NppiSize oSize, int nChannels, size_t * pBufSize);
 
 /**
  * Calculates the size of the temporary buffer for optimize Huffman coding.
  *
- * See \ref nppiGenerateOptimizeHuffmanTable_JPEG.
  * 
  * \param oSize Image Dimension.
  * \param nChannels Number of channels in the image.
@@ -625,6 +678,292 @@ NppStatus nppiEncodeHuffmanGetSize(NppiSize oSize, int nChannels, int * pBufSize
  */
 NppStatus nppiEncodeOptimizeHuffmanGetSize(NppiSize oSize, int nChannels, int * pBufSize);
 
+
+/**
+ * @name Hybrid CPU+GPU JPEG Huffman decoding
+ *
+ * These functions and structs are used for Huffman decoding part of JPEG decode pipeline.
+ * It uses hybrid CPU + GPU approach.
+ *
+ * See \ref nppiJpegDecodeJob for more documentation and example
+ */
+/*@{*/
+
+/**
+ * JPEG frame descriptor.
+ *
+ * Can hold from 1 to 4 components.
+ */
+typedef struct {
+    Npp8u nComponents; /**< Number of components in frame */
+    NppiSize oSizeInBlocks; /**< Size of component with 1x1 subsampling (usually luma) in DCT blocks. */
+    NppiSize aComponentSubsampling[4]; /**< Subsampling factors of component, as described in frame header */
+    Npp16s * apComponentBuffer[4]; /**<
+        Buffer containing DCT coefficients. Use \ref nppiJpegDecodeGetDCTBufferSize to
+        determine size of this buffer. After decoding, coefficients will be stored in
+        zig-zag order, block by block. So the c-th coeffient of block `(x, y)` will
+        be stored at `buffer[64 * (y * interleavedComponentWidthInBlocks + x) + c]`.
+    */
+} NppiJpegFrameDescr; 
+
+/// JPEG scan descriptor
+typedef struct {
+    Npp8u nComponents; /**< Number of components present in scan */
+    Npp8u aComponentIdx[4]; /**< Frame-indexes of components.
+        These values will be used to index arrays in \ref NppiJpegFrameDescr */
+    Npp8u aComponentDcHtSel[4]; /**< DC Huffman table selector per component */
+    Npp8u aComponentAcHtSel[4]; /**< AC Huffman table selector per component */
+    const Npp8u * apRawDcHtTable[4]; /**< Pointers to DC Huffman table description in the raw format
+        (the same format as used in JPEG header).
+        This array will be indexed by \ref aComponentDcHtSel. Pointers for
+        tables unused in scan may be set to NULL. */
+    const Npp8u * apRawAcHtTable[4]; /**< See \ref apRawDcHtTable */
+    Npp8u nSs; /**< Start of spectral selection (index of first coefficient), 0-63 */
+    Npp8u nSe; /**< End of spectral selection (index of first coefficient), 0-63 */
+    Npp8u nAh; /**< Successive approximation bit position high */
+    Npp8u nAl; /**< Successive approximation bit position low */
+    Npp32s restartInterval; /**< Restart interval in MCUs. Use 0 or -1 when none */
+    Npp32s length; /**< Length of compressed (encoded) scan data */
+} NppiJpegScanDescr;
+
+/**
+ * Type of job to execute. Usually you will need just SIMPLE
+ * for each scan, one MEMZERO at the beginning and FINALIZE at the end.
+ * See the example in \ref nppiJpegDecodeJob
+ *
+ * SIMPLE can be split into multiple jobs: PRE, CPU & GPU.
+ * Please note that if you don't use SIMPLE,
+ * you man need to add some memcopies and synchronizes as
+ * described in \ref nppiJpegDecodeJob.
+ *
+ * \sa nppiJpegDecodeJob
+ */
+enum NppiJpegDecodeJobKind {
+    NPPI_JPEG_DECODE_SIMPLE, /**< Decode whole scan using a single job */
+
+    // SIMPLE can be split into:
+    /*@{*/
+    NPPI_JPEG_DECODE_PRE, /**< Preprocessing scan on GPU */
+    NPPI_JPEG_DECODE_CPU, /**< Part of decoding run on CPU */
+    NPPI_JPEG_DECODE_GPU, /**< Part of decoding run on GPU */
+    /*@}*/
+
+    NPPI_JPEG_DECODE_MEMZERO, /**< Zeroing memory before decoding */
+    NPPI_JPEG_DECODE_FINALIZE /**< Change memory representation of DCT coefficients to final */
+};
+
+/**
+ * JPEG decode job used by \ref nppiJpegDecodeJob (see that for more documentation)
+ *
+ * The job describes piece of computation to be done.
+ */
+typedef struct {
+    NppiJpegFrameDescr * pFrame; /**< This field and its contents are never written */
+    NppiJpegScanDescr * pScan; /**< This field is never written. `*pScan` is written
+                                 only by ...Create... functions */
+    enum NppiJpegDecodeJobKind eKind;
+} NppiJpegDecodeJob;
+
+/** Number of additional buffers that may be used by JPEG decode jobs.
+ * This number may change in the future, but it remain small.
+ *
+ * \sa NppiJpegDecodeJobMemory
+ */
+#define NPPI_JPEG_DECODE_N_BUFFERS 3
+
+/**
+ * Memory buffers used by one decode job.
+ *
+ * \sa nppiJpegDecodeJobMemorySize
+ * \sa nppiJpegDecodeJob
+ */
+typedef struct {
+    const Npp8u * pCpuScan;
+    /**< Pointer to host memory containing compressed scan data.
+     * Should be allocated with additional \ref nppiJpegDecodeGetScanDeadzoneSize
+     * bytes of usable memory after the end of compressed scan data.
+     * Should be filled by caller. */
+
+    Npp8u * pGpuScan;
+    /**< Pointer to device memory used for compressed scan data.
+     * Should be allocated with additional \ref nppiJpegDecodeGetScanDeadzoneSize
+     * bytes of usable memory after the end of compressed scan data.
+     * Should be filled by caller.
+     * This buffer may be overwritten by the decoder.
+     * Could be NULL for \ref NPPI_JPEG_DECODE_CPU. */
+
+    void * apCpuBuffer[NPPI_JPEG_DECODE_N_BUFFERS];
+    /**< Pointers to additional host buffers used by job. Call \ref nppiJpegDecodeJobMemorySize
+     * to query sizes of these buffers. `apCpuBuffer[i]` should point to
+     * at least `aSize[i]` bytes. If `aSize[i] == 0`, the pointer should be set to NULL. */
+
+    void * apGpuBuffer[NPPI_JPEG_DECODE_N_BUFFERS];
+    /**< Pointers to additional device buffers used by job.
+     * Minimal sizes of buffers should be the same as the sizes of \ref apCpuBuffer. */
+} NppiJpegDecodeJobMemory;
+
+/**
+ * Calculates sizes of additional buffers used by the job.
+ *
+ * \param pJob has to point to properly initialized job
+ * \param[out] aSize will be filled with \ref NPPI_JPEG_DECODE_N_BUFFERS sizes,
+ * `aSize[i]` telling how much memory has to be allocated for `apCpuBuffer[i]` and `apGpuBuffer[i]`.
+ *
+ * \sa NppiJpegDecodeJobMemory
+ *
+ * \returns
+ * * \ref NPP_SUCCESS
+ * * \ref NPP_BAD_ARGUMENT_ERROR when the scan doesn't represent valid JPEG scan
+ * * \ref NPP_NULL_POINTER_ERROR when one of necessary arguments is NULL
+ */
+NppStatus nppiJpegDecodeJobMemorySize(const NppiJpegDecodeJob * pJob, size_t * aSize);
+
+/**
+ * Executes a job -- part of decoding.
+ *
+ * \param pJob has to be initialized by \ref nppiJpegDecodeJobCreateMemzero
+ * or \ref nppiJpegDecodeJobCreateFinalize or manually.
+ * \param pMemory has to point to valid structure, except for MEMZERO and FINALIZE
+ * scans, for which it can be NULL.
+ *
+ * \sa nppiJpegDecodeJobMemorySize
+ * \sa nppiJpegDecodeJobCreateMemzero
+ * \sa nppiJpegDecodeJobCreateFinalize
+ *
+ * This function can be used in two ways, depending on how much control do you need:
+ * 1. Decode whole scan in one job. That is accomplished when the job.eKind is
+ *    set to \ref NPPI_JPEG_DECODE_SIMPLE. Nppi function handless all in-scan synchronization
+ *    (if needed).
+ *    This is described in example.
+ * 2. Split decoding of scan into multiple jobs. In this case, caller is responsible
+ *    necessary synchronizations. If multiple jobs
+ *    from the same scan claim to use the same additional buffer, it means that
+ *    the jobs are exchaning information throught this buffer and the buffer should not be
+ *    reused or reallocated meanwhile, additionaly if the buffer is used first by PRE job,
+ *    and then by CPU job, caller has to call cudaStreamSynchronize before CPU job.
+ *    \ref NppiJpegDecodeJobKind for more information.
+ *
+ * Example (pseudo)code for decoding JPEG:
+ * (Error handling code omitted for brevity. Each function which may return
+ * an error should be checked)
+ * @code
+ // Allocate DCT buffers (using nppiJpegDecodeGetDCTBufferSize)
+ 
+ NppiJpegFrameDescr frame;
+ // Fill frame info...
+ NppiJpegScanDescr scan;
+ NppiJpegDecodeJob job;
+ job.pFrame = frame;
+ job.pScan = scan;
+ 
+ nppiJpegDecodeJobCreateMemzero(&job);
+ nppiJpegDecodeJob(&job, NULL);
+ for (int i = 0; i < nScans; ++i)
+ {
+     // Fill scan info...
+     job.eKind = NPPI_JPEG_DECODE_SIMPLE;
+ 
+     size_t sizes[NPPI_JPEG_DECODE_N_BUFFERS];
+     nppiJpegDecodeJobMemorySize(&job, sizes);
+ 
+     NppiJpegJobMemory memory;
+     // Allocate and fill scan buffers (using nppiJpegDecodeGetScanBufferSize)...
+     // Fill the memory struct according to sizes...
+ 
+     nppiJpegDecodeJob(&job, &memory);
+ 
+     // Synchronization is needed only if you reuse buffers between scans. 
+     cudaStreamSynchronize(nppGetStream());
+ }
+ 
+ nppiJpegDecodeJobCreateFinalize(&job);
+ nppiJpegDecodeJob(&job, NULL);
+ 
+ // Perform further steps of decoding (iDCT etc.)
+ * @endcode
+ *
+ * \returns
+ * * \ref NPP_SUCCESS
+ * * \ref NPP_BAD_ARGUMENT_ERROR when the scan doesn't represent valid JPEG scan
+ * * \ref NPP_NULL_POINTER_ERROR when one of necessary arguments of buffers is NULL
+ * * \ref NPP_ERROR when encountered CUDA error
+ */
+NppStatus nppiJpegDecodeJob(const NppiJpegDecodeJob * pJob, const NppiJpegDecodeJobMemory * pMemory);
+
+/**
+ * Initializes a job that has to be called at the beginning of decoding.
+ *
+ * \param pJob:
+ * `pJob.pFrame` should point to valid frame description.
+ * `*pJob.pScan` will be overwritten.
+ *
+ * If the caller had manually zeroed the memory for DCT buffers,
+ * (note: whole \ref nppiJpegDecodeDCTBufferSize has to be zeroed).
+ * this job doesn't have to be executed.
+ */
+NppStatus nppiJpegDecodeJobCreateMemzero(NppiJpegDecodeJob * pJob);
+
+/**
+ * Initializes a job that has to be called at the end of decoding,
+ * in order to convert temporary representation of DCT coefficients
+ * to the final one.
+ *
+ * \param pJob:
+ * pJob.pFrame should point to valid frame description
+ * *pJob.pScan will be overwritten.
+ */
+NppStatus nppiJpegDecodeJobCreateFinalize(NppiJpegDecodeJob * pJob);
+
+/**
+ * This function returns how much additional memory has to be available
+ * after the end of compressed scan data.
+ *
+ * The following buffers: `pCpuScan` and `pGpuScan` in \ref NppiJpegDecodeJobMemory
+ * should have size at least `pScan->length + nppiJpegDecodeGetScanDeadzoneSize()`.
+ *
+ * The additional memory is needed because the decoder may perform
+ * some speculative reads after the end of compressed scan data.
+ */
+size_t nppiJpegDecodeGetScanDeadzoneSize(void);
+
+/**
+ * Returns how much memory has to be allocated for DCT coefficient buffers
+ * declared in \ref NppiJpegDecodeJobMemory. The returned value may be bigger than
+ * simply `number of blocks * 64 * sizeof (short)`, because decoder
+ * may use slightly bigger temporary representation of data.
+ *
+ * \param oBlocks Size of the interleaved component in blocks.
+ * (That means that the size of component in blocks has to be aligned according
+ * to subsampling of this component and frame).
+ * 
+ * This function assumes no ununsed space between rows,
+ * so at the end stride = `oBlocks.width * 64 * sizeof (short)`.
+ */
+size_t nppiJpegDecodeGetDCTBufferSize(NppiSize oBlocks);
+
+/*@}*/
+
+/**
+ * Inverse DCT in WebP decoding. Input is the bitstream that contains the coefficients of 16x16 blocks.
+ * These coefficients are based on a 4x4 sub-block unit, e.g., 
+ * Coeffs in 0th 4x4 block, 1st 4x4 block 2nd 4x4 block, etc.
+ * Output is the coefficients after inverse DCT transform.
+ * The output is put in an image format (i.e. raster scan order), different from the input order.
+ *
+ * \param pSrc \ref source_image_pointer.
+ * \param nSrcStep \ref source_image_line_step.
+ * \param pDst \ref destination_image_pointer.
+ * \param nDstStep \ref destination_image_line_step.
+ * \param oSizeROI \ref roi_specification.
+ * \return Error codes:
+ *         - ::NPP_SIZE_ERROR For negative input height/width or not a multiple of
+ *           8 width/height.
+ *         - ::NPP_STEP_ERROR If input image width is not multiple of 8 or does not
+ *           match ROI.
+ *         - ::NPP_NULL_POINTER_ERROR If the destination pointer is 0.
+ */
+NppStatus nppiDCTInv4x4_WebP_16s_C1R(const Npp16s * pSrc, int nSrcStep, Npp16s * pDst, int nDstStep, NppiSize oSizeROI);
+
 /** @} image_compression */
 
 
