@@ -51,7 +51,7 @@
 #define __SM_20_INTRINSICS_H__
 
 #if defined(__CUDACC_RTC__)
-#define __SM_20_INTRINSICS_DECL__ __host__ __device__
+#define __SM_20_INTRINSICS_DECL__ __device__
 #else /* __CUDACC_RTC__ */
 #define __SM_20_INTRINSICS_DECL__ static __inline__ __device__
 #endif /* __CUDACC_RTC__ */
@@ -74,11 +74,23 @@
 #define __DEF_IF_HOST ;
 #endif /* __CUDA_ARCH__ */
 
+#if defined(_WIN32)
+# define __DEPRECATED__(msg) __declspec(deprecated(msg))
+#elif (defined(__GNUC__) && (__GNUC__ < 4 || (__GNUC__ == 4 && __GNUC_MINOR__ < 5 && !defined(__clang__))))
+# define __DEPRECATED__(msg) __attribute__((deprecated))
+#else
+# define __DEPRECATED__(msg) __attribute__((deprecated(msg)))
+#endif
+
+#if defined(__CUDA_ARCH__) && __CUDA_ARCH__ >= 700
+#define __WSB_DEPRECATION_MESSAGE(x) #x"() is not valid on compute_70 and above, and should be replaced with "#x"_sync()."\
+    "To continue using "#x"(), specify virtual architecture compute_60 when targeting sm_70 and above, for example, using the pair of compiler options: -arch=compute_60 -code=sm_70."
+#else
+#define __WSB_DEPRECATION_MESSAGE(x) #x"() is deprecated in favor of "#x"_sync() and may be removed in a future release (Use -Wno-deprecated-declarations to suppress this warning)."
+#endif
 
-#if !defined(__CUDACC_RTC__)
 extern "C"
 {
-#endif /* !__CUDACC_RTC__ */
 extern __device__ __device_builtin__ void                   __threadfence_system(void);
 /**
  * \ingroup CUDA_MATH_INTRINSIC_DOUBLE
@@ -392,7 +404,7 @@ extern __device__ __device_builtin__ double                __dsqrt_ru(double x);
  * \note_requires_fermi
  */
 extern __device__ __device_builtin__ double                __dsqrt_rd(double x);
-extern __device__ __device_builtin__ unsigned int          __ballot(int);
+extern __device__ __device_builtin__ __DEPRECATED__(__WSB_DEPRECATION_MESSAGE(__ballot)) unsigned int __ballot(int);
 extern __device__ __device_builtin__ int                   __syncthreads_count(int);
 extern __device__ __device_builtin__ int                   __syncthreads_and(int);
 extern __device__ __device_builtin__ int                   __syncthreads_or(int);
@@ -1462,17 +1474,14 @@ extern __device__ __device_builtin__ int                    __double2loint(doubl
 extern __device__ __device_builtin__ double                 __hiloint2double(int hi, int lo);
 
 
-#if !defined(__CUDACC_RTC__)
 }
-#endif /* !__CUDACC_RTC__ */
 
 /*******************************************************************************
 *                                                                              *
 *                                                                              *
 *                                                                              *
 *******************************************************************************/
-
-__SM_20_INTRINSICS_DECL__ unsigned int ballot(bool pred) __DEF_IF_HOST
+__SM_20_INTRINSICS_DECL__ __DEPRECATED__(__WSB_DEPRECATION_MESSAGE(__ballot)) unsigned int ballot(bool pred) __DEF_IF_HOST
 
 __SM_20_INTRINSICS_DECL__ int syncthreads_count(bool pred) __DEF_IF_HOST
 
@@ -1480,6 +1489,8 @@ __SM_20_INTRINSICS_DECL__ bool syncthreads_and(bool pred) __DEF_IF_HOST
 
 __SM_20_INTRINSICS_DECL__ bool syncthreads_or(bool pred) __DEF_IF_HOST
 
+#undef __DEPRECATED__
+#undef __WSB_DEPRECATION_MESSAGE
 
 // This function returns 1 if generic address "ptr" is in global memory space.
 // It returns 0 if "ptr" is in shared, local or constant memory space.
