@@ -51,7 +51,7 @@
 #define __SM_32_INTRINSICS_HPP__
 
 #if defined(__CUDACC_RTC__)
-#define __SM_32_INTRINSICS_DECL__ __host__ __device__
+#define __SM_32_INTRINSICS_DECL__ __device__
 #else /* !__CUDACC_RTC__ */
 #define __SM_32_INTRINSICS_DECL__ static __device__ __inline__
 #endif /* __CUDACC_RTC__ */
