@@ -52,7 +52,7 @@
 
 
 #if defined(__CUDACC_RTC__)
-#define __SM_60_ATOMIC_FUNCTIONS_DECL__ __host__ __device__
+#define __SM_60_ATOMIC_FUNCTIONS_DECL__ __device__
 #else /* __CUDACC_RTC__ */
 #define __SM_60_ATOMIC_FUNCTIONS_DECL__ static __inline__ __device__
 #endif /* __CUDACC_RTC__ */
@@ -79,10 +79,8 @@
 
 
 #ifdef __CUDA_ARCH__ 
-#if !defined(__CUDACC_RTC__)
 extern "C"
 {
-#endif /* !__CUDACC_RTC__ */
 extern __device__ __device_builtin__ double __dAtomicAdd(double *address, double val);
 
 extern __device__ __device_builtin__
@@ -294,9 +292,7 @@ unsigned long long __ullAtomicXor_block(unsigned long long *address, unsigned lo
 
 extern __device__ __device_builtin__
 unsigned long long __ullAtomicXor_system(unsigned long long *address, unsigned long long val);
-#if !defined(__CUDACC_RTC__)
 }
-#endif /* !__CUDACC_RTC__ */
 #endif /* __CUDA_ARCH__ */
 
 /*******************************************************************************
@@ -337,6 +333,18 @@ double atomicAdd_block(double *address, double val) __DEF_IF_HOST
 __SM_60_ATOMIC_FUNCTIONS_DECL__
 double atomicAdd_system(double *address, double val) __DEF_IF_HOST
 
+__SM_60_ATOMIC_FUNCTIONS_DECL__
+int atomicSub_block(int *address, int val) __DEF_IF_HOST
+
+__SM_60_ATOMIC_FUNCTIONS_DECL__
+int atomicSub_system(int *address, int val) __DEF_IF_HOST
+
+__SM_60_ATOMIC_FUNCTIONS_DECL__
+unsigned int atomicSub_block(unsigned int *address, unsigned int val) __DEF_IF_HOST
+
+__SM_60_ATOMIC_FUNCTIONS_DECL__
+unsigned int atomicSub_system(unsigned int *address, unsigned int val) __DEF_IF_HOST
+
 __SM_60_ATOMIC_FUNCTIONS_DECL__
 int atomicExch_block(int *address, int val) __DEF_IF_HOST
 
